Interfaces, exceptions and utils
================================

Connection Clients
------------------

Interface
~~~~~~~~~

.. automodule:: bleak.backends.client
    :members:

Windows
~~~~~~~

.. automodule:: bleak.backends.winrt.client
    :members:

macOS
~~~~~

.. automodule:: bleak.backends.corebluetooth.client
    :members:

Linux Distributions with BlueZ
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: bleak.backends.bluezdbus.client
    :members:

Python-for-Android/Kivy
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: bleak.backends.p4android.client
    :members:

Scanning Clients
----------------

Interface
~~~~~~~~~

.. automodule:: bleak.backends.scanner
    :members:

Windows
~~~~~~~

.. automodule:: bleak.backends.winrt.scanner
    :members:

macOS
~~~~~

.. automodule:: bleak.backends.corebluetooth.scanner
    :members:

Linux Distributions with BlueZ
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: bleak.backends.bluezdbus.scanner
    :members:

Python-for-Android/Kivy
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: bleak.backends.p4android.scanner
    :members:


Class representing BLE devices
------------------------------

Generated by :py:meth:`bleak.discover` and :py:class:`bleak.backends.scanning.BaseBleakScanner`.

.. automodule:: bleak.backends.device
    :members:

GATT objects
------------

.. automodule:: bleak.backends.service
    :members:

.. automodule:: bleak.backends.characteristic
    :members:

.. automodule:: bleak.backends.descriptor
    :members:


Exceptions
----------

.. automodule:: bleak.exc
    :members:

Utilities
---------

.. automodule:: bleak.uuids
    :members:
